==> zio-aws-apigatewayv2_2.12-5.17.116.2-sources.jar: zio/aws/apigatewayv2/model/GetIntegrationResponseRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class GetIntegrationResponseRequest(
    apiId: __string,
    integrationId: __string,
    integrationResponseId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationResponseRequest = {
    import GetIntegrationResponseRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationResponseRequest
      .builder()
      .apiId(__string.unwrap(apiId): java.lang.String)
      .integrationId(__string.unwrap(integrationId): java.lang.String)
      .integrationResponseId(
        __string.unwrap(integrationResponseId): java.lang.String
      )
      .build()
  }
  def asReadOnly
      : zio.aws.apigatewayv2.model.GetIntegrationResponseRequest.ReadOnly =
    zio.aws.apigatewayv2.model.GetIntegrationResponseRequest
      .wrap(buildAwsValue())
}
object GetIntegrationResponseRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationResponseRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetIntegrationResponseRequest =
      zio.aws.apigatewayv2.model.GetIntegrationResponseRequest(
        apiId,
        integrationId,
        integrationResponseId
      )
    def apiId: __string
    def integrationId: __string
    def integrationResponseId: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getIntegrationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(integrationId)
    def getIntegrationResponseId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(integrationResponseId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationResponseRequest
  ) extends zio.aws.apigatewayv2.model.GetIntegrationResponseRequest.ReadOnly {
    override val apiId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.apiId())
    override val integrationId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.integrationId())
    override val integrationResponseId: __string =
      zio.aws.apigatewayv2.model.primitives
        .__string(impl.integrationResponseId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationResponseRequest
  ): zio.aws.apigatewayv2.model.GetIntegrationResponseRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-apigatewayv2_2.13-5.19.31.1-sources.jar: zio/aws/apigatewayv2/model/GetIntegrationResponseRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class GetIntegrationResponseRequest(
    apiId: __string,
    integrationId: __string,
    integrationResponseId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationResponseRequest = {
    import GetIntegrationResponseRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationResponseRequest
      .builder()
      .apiId(apiId: java.lang.String)
      .integrationId(integrationId: java.lang.String)
      .integrationResponseId(integrationResponseId: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.apigatewayv2.model.GetIntegrationResponseRequest.ReadOnly =
    zio.aws.apigatewayv2.model.GetIntegrationResponseRequest
      .wrap(buildAwsValue())
}
object GetIntegrationResponseRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationResponseRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetIntegrationResponseRequest =
      zio.aws.apigatewayv2.model.GetIntegrationResponseRequest(
        apiId,
        integrationId,
        integrationResponseId
      )
    def apiId: __string
    def integrationId: __string
    def integrationResponseId: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getIntegrationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(integrationId)
    def getIntegrationResponseId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(integrationResponseId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationResponseRequest
  ) extends zio.aws.apigatewayv2.model.GetIntegrationResponseRequest.ReadOnly {
    override val apiId: __string = impl.apiId(): __string
    override val integrationId: __string = impl.integrationId(): __string
    override val integrationResponseId: __string =
      impl.integrationResponseId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetIntegrationResponseRequest
  ): zio.aws.apigatewayv2.model.GetIntegrationResponseRequest.ReadOnly =
    new Wrapper(impl)
}
